# Botan base spec file

# Note that some of the commands in here assume a GNU toolset, which is
# unfortunate and should probably be fixed.

##################################################
# Hardware restrictions on various modules       #
##################################################
%define USE_TM_HARD i586 i686 athlon x86_64 alpha sparcv9 sparc64
%define USE_MP64    alpha ppc64 ia64 x86_64

##################################################
# Version numbers and config options             #
##################################################
%define MAJOR $MAJOR
%define MINOR $MINOR
%define PATCH $PATCH

# This is the list of modules built into the library. We also include the
# 'unix' module set.
%define THREADS      mux_pthr
%define COMPRESSION  comp_bzip2,comp_zlib

%ifarch %{USE_TM_HARD}
  %define TIMERS     tm_posix,tm_hard
%else
  %define TIMERS     tm_posix
%endif

%ifarch %{USE_MP64}
  %define MPI_MODS   mp_asm64,mp_gmp
%else
  %define MPI_MODS   mp_gmp
%endif

%define MODULES %{TIMERS},%{THREADS},%{COMPRESSION},%{MPI_MODS}

##################################################
# Descriptions                                   #
##################################################
%define VERSION %{MAJOR}.%{MINOR}.%{PATCH}

Name: Botan
Summary: A C++ crypto library
Version: %{VERSION}
Release: 1
License: BSD
Group: System Environment/Libraries
Source: http://botan.randombit.net/botan/files/%{name}-%{VERSION}.tgz
URL: http://botan.randombit.net
Packager: Jack Lloyd <lloyd@randombit.net>
Requires: bzip2 >= 1.0.2, zlib >= 1.1.4, gmp >= 4.1
Prefix: /usr

BuildRoot: %{_tmppath}/%{name}-%{version}-root
BuildRequires: perl, make, gcc-c++, zlib-devel, bzip2-devel, gmp-devel

%description
Botan is a C++ library which provides support for many common cryptographic
operations, including encryption, authentication, and X.509v3 certificates and
CRLs. A wide variety of algorithms is supported, including RSA, DSA, DES, AES,
MD5, and SHA-1.

%package devel
Summary: Development files for Botan
Group: Development/Libraries
Requires: Botan = %{VERSION}
%description devel
This package contains the header files and libraries needed to develop programs
that use the Botan library.

##################################################
# Main Logic                                     #
##################################################
%prep
%setup -n Botan-%{VERSION}

%build
./configure.pl --module-set=unix --modules=%{MODULES} \
  gcc-%{_target_os}-%{_target_cpu}
make shared static

%clean
rm -rf $RPM_BUILD_ROOT

%install
ROOT="$RPM_BUILD_ROOT/usr"
make OWNER=`id -u` GROUP=`id -g` INSTALLROOT=$ROOT install

# Need this since we're installing shared libs...
%post
if ! grep "^$RPM_INSTALL_PREFIX/lib$" /etc/ld.so.conf 2>&1 >/dev/null
then
   echo "$RPM_INSTALL_PREFIX/lib" >>/etc/ld.so.conf
fi
/sbin/ldconfig -X

%postun
RMDIR_IGNORE_NONEMPTY="rmdir --ignore-fail-on-non-empty"
/sbin/ldconfig -X
if [ -d $RPM_INSTALL_PREFIX/share/doc/Botan-%{VERSION} ]; then
   $RMDIR_IGNORE_NONEMPTY $RPM_INSTALL_PREFIX/share/doc/Botan-%{VERSION}
fi

%postun devel
RMDIR_IGNORE_NONEMPTY="rmdir --ignore-fail-on-non-empty"
if [ -d $RPM_INSTALL_PREFIX/include/botan ]; then
   $RMDIR_IGNORE_NONEMPTY $RPM_INSTALL_PREFIX/include/botan
fi

##################################################
# File Lists                                     #
##################################################
%files
%attr(-,root,root) %docdir /usr/share/doc/Botan-%{VERSION}/
%attr(-,root,root) /usr/share/doc/Botan-%{VERSION}/license.txt
%attr(-,root,root) /usr/share/doc/Botan-%{VERSION}/readme.txt
%attr(-,root,root) /usr/share/doc/Botan-%{VERSION}/log.txt
%attr(-,root,root) /usr/share/doc/Botan-%{VERSION}/thanks.txt
%attr(-,root,root) /usr/share/doc/Botan-%{VERSION}/authors.txt
%attr(-,root,root) /usr/share/doc/Botan-%{VERSION}/pgpkeys.asc
%attr(-,root,root) /usr/lib/libbotan-%{MAJOR}.so
%attr(-,root,root) /usr/lib/libbotan-%{MAJOR}.%{MINOR}.so
%attr(-,root,root) /usr/lib/libbotan-%{MAJOR}.%{MINOR}.%{PATCH}.so

%files devel
%attr(-,root,root) %docdir /usr/share/doc/Botan-%{VERSION}/
%attr(-,root,root) /usr/share/doc/Botan-%{VERSION}/api.tex
%attr(-,root,root) /usr/share/doc/Botan-%{VERSION}/api.pdf
%attr(-,root,root) /usr/share/doc/Botan-%{VERSION}/tutorial.tex
%attr(-,root,root) /usr/share/doc/Botan-%{VERSION}/tutorial.pdf
%attr(-,root,root) /usr/share/doc/Botan-%{VERSION}/deprecated.txt
%attr(-,root,root) /usr/share/doc/Botan-%{VERSION}/todo.txt
%attr(-,root,root) /usr/share/doc/Botan-%{VERSION}/bugs.txt
%attr(-,root,root) /usr/share/doc/Botan-%{VERSION}/rngs.txt
%attr(-,root,root) /usr/share/doc/Botan-%{VERSION}/botan.rc
%attr(-,root,root) /usr/lib/libbotan.so
%attr(-,root,root) /usr/lib/libbotan.a
%attr(-,root,root) /usr/include/botan/
%attr(-,root,root) /usr/bin/botan-config

##################################################
# Changelog                                      #
##################################################
%changelog
* 30/11/2003
 - Default to installing into /usr instead of /usr/local
 - Use tm_hard on sparcv9

* 23/11/2003
 - Cleaned up the declaration of TIMERS
