/*************************************************
* MP Dword Functions Source File                 *
* (C) 1999-2003 The Botan Project                *
*************************************************/

#include <botan/mp_impl.h>

extern "C" {

/*************************************************
* Do a 2-word/1-word Division                    *
*************************************************/
word bigint_divop(word n1, word n0, word d)
   {
   word high = n1 % d;
   word quotient = 0;
   for(u32bit j = 0; j != MP_WORD_BITS; j++)
      {
      const word mask = (word)1 << (MP_WORD_BITS-1-j);
      const bool high_top_bit = (high & MP_WORD_TOP_BIT) ? true : false;

      high = (high << 1) | ((n0 & mask) >> (MP_WORD_BITS-1-j));

      if(high_top_bit || high >= d)
         {
         high -= d;
         quotient |= mask;
         }
      }
   return quotient;
   }

/*************************************************
* Do a 2-word/1-word Modulo                      *
*************************************************/
word bigint_modop(word n1, word n0, word d)
   {
   word z0 = n1 / d, z1 = bigint_divop(n1, n0, d);
   word carry = 0;
   bigint_madd(z1, d,     0, 0, &z1, &carry);
   bigint_madd(z0, d, carry, 0, &z0, &carry);
   return (n0-z1);
   }

}
